@@ -1,8 +1,6 @@
 
 __all__ = ['descriptive', 'paired_t_test', 'unpaired_t_test']
 
-# from . import *
-
 
 def initiate(names_submodules=None):
     template_import_string = "from . import "
@@ -17,11 +15,12 @@ def initiate(names_submodules=None):
                 import_string_m = template_import_string + str(name_m)
             exec(import_string_m)
     elif names_submodules is None:
-        for name_m in __all__:
-            if isinstance(name_m, str):
-                import_string_m = template_import_string + name_m
-            else:
-                import_string_m = template_import_string + str(name_m)
-            exec(import_string_m)
+        exec('from . import *')
+        # for name_m in __all__:
+        #     if isinstance(name_m, str):
+        #         import_string_m = template_import_string + name_m
+        #     else:
+        #         import_string_m = template_import_string + str(name_m)
+        #     exec(import_string_m)
     else:
         raise TypeError(names_submodules)
